package com.zd.laboratory.mapper;

import java.util.List;
import com.zd.laboratory.domain.LabNegativeListSite;

/**
 * 负面清单设置Mapper接口
 * 
 * @author zd
 * @date 2021-12-14
 */
public interface LabNegativeListSiteMapper 
{
    /**
     * 查询负面清单设置
     * 
     * @param id 负面清单设置主键
     * @return 负面清单设置
     */
    public LabNegativeListSite selectLabNegativeListSiteById(Long id);

    /**
     * 查询负面清单设置列表
     * 
     * @param labNegativeListSite 负面清单设置
     * @return 负面清单设置集合
     */
    public List<LabNegativeListSite> selectLabNegativeListSiteList(LabNegativeListSite labNegativeListSite);

    /**
     * 新增负面清单设置
     * 
     * @param labNegativeListSite 负面清单设置
     * @return 结果
     */
    public int insertLabNegativeListSite(LabNegativeListSite labNegativeListSite);

    /**
     * 修改负面清单设置
     * 
     * @param labNegativeListSite 负面清单设置
     * @return 结果
     */
    public int updateLabNegativeListSite(LabNegativeListSite labNegativeListSite);

    /**
     * 删除负面清单设置
     * 
     * @param id 负面清单设置主键
     * @return 结果
     */
    public int deleteLabNegativeListSiteById(Long id);

    /**
     * 批量删除负面清单设置
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteLabNegativeListSiteByIds(Long[] ids);
}
