package com.zd.laboratory.controller;

import java.util.List;
import java.io.IOException;
import javax.servlet.http.HttpServletResponse;

import com.zd.common.core.domain.per.PerFun;
import com.zd.common.core.domain.per.PerPrefix;
import com.zd.common.core.web.domain.ResultData;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.zd.common.log.annotation.Log;
import com.zd.common.log.enums.BusinessType;
import com.zd.common.security.annotation.PreAuthorize;
import com.zd.laboratory.domain.LabNegativeListSite;
import com.zd.laboratory.service.ILabNegativeListSiteService;
import com.zd.common.core.web.controller.BaseController;
import com.zd.common.core.web.domain.AjaxResult;
import com.zd.common.core.utils.poi.ExcelUtil;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import com.zd.common.swagger.config.Knife4jConfiguration;

import com.zd.common.core.web.page.TableDataInfo;

/**
 * 负面清单设置Controller
 *
 * @author zd
 * @date 2021-12-14
 */
@RestController
@Api(tags = "【负面清单设置】")
//作者手动加入 ，在接口上加作者@ApiOperationSupport(author = "XXX")
@RequestMapping("/negativeListSite")
public class LabNegativeListSiteController extends BaseController
{
    @Autowired
    private ILabNegativeListSiteService labNegativeListSiteService;

    /**
     * 查询负面清单设置列表
     */
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.LIST)
    @GetMapping("/list")
    @ApiOperation(value = "查询负面清单设置列表")
    public TableDataInfo<LabNegativeListSite> list(LabNegativeListSite labNegativeListSite)
    {
        startPage();
        List<LabNegativeListSite> list = labNegativeListSiteService.selectLabNegativeListSiteList(labNegativeListSite);
        return getDataTable(list);
    }

    /**
     * 导出负面清单设置列表
     */
    @ApiOperation(value = "导出负面清单设置列表")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.EXPORT)
    @Log(title = "负面清单设置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, LabNegativeListSite labNegativeListSite) throws IOException
    {
        List<LabNegativeListSite> list = labNegativeListSiteService.selectLabNegativeListSiteList(labNegativeListSite);
        ExcelUtil<LabNegativeListSite> util = new ExcelUtil<LabNegativeListSite>(LabNegativeListSite.class);
        util.exportExcel(response, list, "负面清单设置数据");
    }

    /**
     * 获取负面清单设置详细信息
     */
    @ApiOperation(value = "获取负面清单设置详细信息")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.QUERY)
    @GetMapping(value = "/{id}")
    public ResultData<LabNegativeListSite> getInfo(@PathVariable("id") Long id)
    {
        return ResultData.success(labNegativeListSiteService.selectLabNegativeListSiteById(id));
    }

    /**
     * 新增负面清单设置
     */
    @ApiOperation(value = "新增负面清单设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.ADD)
    @Log(title = "负面清单设置", businessType = BusinessType.INSERT)
    @PostMapping
    public ResultData add(@RequestBody LabNegativeListSite labNegativeListSite)
    {
        return ResultData.result(labNegativeListSiteService.insertLabNegativeListSite(labNegativeListSite));
    }

    /**
     * 修改负面清单设置
     */
    @ApiOperation(value = "修改负面清单设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.EDIT)
    @Log(title = "负面清单设置", businessType = BusinessType.UPDATE)
    @PutMapping
    public ResultData edit(@RequestBody LabNegativeListSite labNegativeListSite)
    {
        return  ResultData.result(labNegativeListSiteService.updateLabNegativeListSite(labNegativeListSite));
    }

    /**
     * 删除负面清单设置
     */
    @ApiOperation(value = "删除负面清单设置")
    @PreAuthorize(hasPermi = PerPrefix.LABORATORY_NEGATIVELISTSITE + PerFun.REMOVE)
    @Log(title = "负面清单设置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public ResultData remove(@PathVariable Long[] ids)
    {
        return ResultData.result(labNegativeListSiteService.deleteLabNegativeListSiteByIds(ids));
    }
}
